# fumi

A small and (hopefully) simple deploying tool.

Source code available at
[https://github.com/rmed/fumi](https://github.com/rmed/fumi)

---

## Installation

*fumi* is available in the Python Package Index. In order to install it, you
can use **pip**:

    $ pip install fumi

It is also possible to install *fumi* manually by downloading and extracting
the source and running:

    $ python setup.py install

The code is compatible with Python >= 2.6 and Python 3+ (tested with 2.7 and
3.4), so you may use `pip3`, `python3`, etc in order to install.

In addition, the following dependencies will be installed:

- blessings
- paramiko
- pyyaml
- scp
